@@ -332,6 +332,10 @@ def get_widths_heights_for_tabulated_record(record):
 
 def cross_section_configuration_for_record(record):
     if record.cross_section_shape.is_tabulated:
+        # Handle empty cross section table by returning all None to prevent issues in parsing
+        # Note that CrossSectionNullCheck already checks for this
+        if record.cross_section_table is None or record.cross_section_table == "":
+            return None, None, None
         widths, heights = get_widths_heights_for_tabulated_record(record)
         return cross_section_configuration_tabulated(
             shape=record.cross_section_shape, widths=widths, heights=heights
@@ -440,6 +444,15 @@ class CrossSectionMinimumDiameterCheck(CrossSectionBaseCheck):
     def description(self):
         return f"{self.table.name}.cross_section_width and/or cross_section_height should be at least 0.1m"
 
+    def to_check(self, session):
+        return (
+            super()
+            .to_check(session)
+            .where(
+                self.table.c.cross_section_shape.isnot(None),
+            )
+        )
+
 
 class OpenIncreasingCrossSectionCheck(CrossSectionBaseCheck):
     def get_invalid(self, session):
@@ -474,6 +487,13 @@ class OpenIncreasingCrossSectionCheck(CrossSectionBaseCheck):
     def description(self):
         return f"{self.column_name} can only be used in an open channel with monotonically increasing width values"
 
+    def to_check(self, session):
+        return (
+            super()
+            .to_check(session)
+            .where(self.table.c.cross_section_shape.isnot(None))
+        )
+
 
 class OpenIncreasingCrossSectionConveyanceFrictionCheck(
     OpenIncreasingCrossSectionCheck
