@@ -1,4 +1,5 @@
 import re
+from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from typing import List, Literal, NamedTuple
 
@@ -321,25 +322,27 @@ class ConnectionNodesDistance(BaseCheck):
         distance between all connection nodes.
         """
         query = text(
-            f"""
+            """
             SELECT *
             FROM connection_node AS cn1, connection_node AS cn2
-            WHERE ST_Distance(cn1.geom, cn2.geom) < {self.minimum_distance}
+            WHERE ST_Distance(cn1.geom, cn2.geom) < :minimum_distance
             AND cn1.ROWID != cn2.ROWID
             AND cn2.ROWID IN (
                 SELECT ROWID
                 FROM rtree_connection_node_geom
                 WHERE (
-                    maxx >= ST_MinX(ST_Buffer(cn1.geom, {self.minimum_distance / 2}))
-                    AND minx <= ST_MaxX(ST_Buffer(cn1.geom, {self.minimum_distance / 2}))
-                    AND maxy >= ST_MinY(ST_Buffer(cn1.geom, {self.minimum_distance / 2}))
-                    AND miny <= ST_MaxY(ST_Buffer(cn1.geom, {self.minimum_distance / 2}))
+                    maxx >= ST_MinX(ST_Buffer(cn1.geom, :buffer_distance))
+                    AND minx <= ST_MaxX(ST_Buffer(cn1.geom, :buffer_distance))
+                    AND maxy >= ST_MinY(ST_Buffer(cn1.geom, :buffer_distance))
+                    AND miny <= ST_MaxY(ST_Buffer(cn1.geom, :buffer_distance))
                 )
             )
             """
+        ).bindparams(
+            minimum_distance=self.minimum_distance,
+            buffer_distance=self.minimum_distance / 2,
         )
-        results = session.connection().execute(query).fetchall()
-        return results
+        return session.execute(query).fetchall()
 
     def description(self) -> str:
 
@@ -395,6 +398,7 @@ class ChannelManholeLevelCheck(BaseCheck):
         channels_with_cs_locations = (
             session.query(
                 models.Channel.id,
+                models.Channel.geom,
                 models.CrossSectionLocation,
                 func_agg(
                     func.Line_Locate_Point(
@@ -870,7 +874,7 @@ class AllPresentVegetationParameters(BaseCheck):
         )
 
 
-class UsedSettingsPresentCheck(BaseCheck):
+class SettingsPresentCheck(BaseCheck, ABC):
     def __init__(
         self,
         column,
@@ -882,15 +886,53 @@ class UsedSettingsPresentCheck(BaseCheck):
         super().__init__(column, filters, level, error_code)
         self.settings_tables = settings_tables
 
+    @abstractmethod
+    def get_all_results(self, session):
+        pass
+
+    @abstractmethod
+    def get_table_condition(self, session):
+        pass
+
     def get_invalid(self, session: Session) -> List[NamedTuple]:
         # more than 1 row should be caught by another check
-        all_results = self.to_check(session).filter(self.column == True).all()
-        use_cols = len(all_results) > 0
-        for table in self.settings_tables:
-            if use_cols and session.query(table).count() == 0:
-                return all_results
+        all_results = self.get_all_results(session)
+        not_use_cols = len(all_results) == 1
+        # return as invalid if the use_col is true but none of the associated tables are actually used
+        if not_use_cols and self.get_table_condition(session):
+            return all_results
         return []
 
+
+class UnusedSettingsPresentCheck(SettingsPresentCheck):
+
+    def get_all_results(self, session):
+        return self.to_check(session).filter(self.column == False).all()
+
+    def get_table_condition(self, session):
+        return any(session.query(table).count() > 0 for table in self.settings_tables)
+
+    def description(self) -> str:
+        msg = f"{self.column_name} in {self.table.name} is not set to True but "
+        if len(self.settings_tables) == 1:
+            msg += "{self.settings_tables[0].__tablename__} is not empty"
+        else:
+            msg += (
+                "["
+                + ",".join(table.__tablename__ for table in self.settings_tables)
+                + "] are not empty"
+            )
+        return msg
+
+
+class UsedSettingsPresentCheck(SettingsPresentCheck):
+
+    def get_all_results(self, session):
+        return self.to_check(session).filter(self.column == True).all()
+
+    def get_table_condition(self, session):
+        return all(session.query(table).count() == 0 for table in self.settings_tables)
+
     def description(self) -> str:
         msg = f"{self.column_name} in {self.table.name} is set to True but "
         if len(self.settings_tables) == 1:
