@@ -343,6 +343,7 @@ def test_check_yz_increasing_if_open(session, cross_section_table, valid):
             None,
             0,
         ),  # open rectangle, sufficient width, no height, pass
+        (None, None, None, 0),  # no shape, should skip tests
     ],
 )
 def test_check_cross_section_minimum_diameter(
@@ -368,6 +369,7 @@ def test_check_cross_section_minimum_diameter(
             1,
         ),  # closed rectangle, fail
         (constants.CrossSectionShape.RECTANGLE, "0.1", None, 0),  # open rectangle, pass
+        (None, None, None, 0),
     ],
 )
 @pytest.mark.parametrize(
@@ -630,6 +632,16 @@ def test_cross_section_configuration_not_tabulated_raise():
             {"cross_section_width": 1, "cross_section_height": 2},
             (1, 2, "closed"),
         ),
+        (
+            constants.CrossSectionShape.TABULATED_YZ,
+            {},
+            (None, None, None),
+        ),
+        (
+            constants.CrossSectionShape.TABULATED_YZ,
+            {"cross_section_table": ""},
+            (None, None, None),
+        ),
     ],
 )
 def test_cross_section_configuration_for_record(session, shape, kwargs, expected):
